AssociatedGateway class

Information about the associated gateway.

Constructors

AssociatedGateway({String? id, String? ownerAccount, String? region, GatewayType? type})
AssociatedGateway.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
The ID of the associated gateway.
final
ownerAccount → String?
The ID of the AWS account that owns the associated virtual private gateway or transit gateway.
final
region → String?
The Region where the associated gateway is located.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → GatewayType?
The type of associated gateway.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited