Connection class

Information about an AWS Direct Connect connection.

Constructors

Connection({String? awsDevice, String? awsDeviceV2, String? bandwidth, String? connectionId, String? connectionName, ConnectionState? connectionState, HasLogicalRedundancy? hasLogicalRedundancy, bool? jumboFrameCapable, String? lagId, DateTime? loaIssueTime, String? location, String? ownerAccount, String? partnerName, String? providerName, String? region, List<Tag>? tags, int? vlan})
Connection.fromJson(Map<String, dynamic> json)
factory

Properties

awsDevice → String?
The Direct Connect endpoint on which the physical connection terminates.
final
awsDeviceV2 → String?
The Direct Connect endpoint on which the physical connection terminates.
final
bandwidth → String?
The bandwidth of the connection.
final
connectionId → String?
The ID of the connection.
final
connectionName → String?
The name of the connection.
final
connectionState → ConnectionState?
The state of the connection. The following are the possible values:
final
hashCode → int
The hash code for this object.
no setterinherited
hasLogicalRedundancy → HasLogicalRedundancy?
Indicates whether the connection supports a secondary BGP peer in the same address family (IPv4/IPv6).
final
jumboFrameCapable → bool?
Indicates whether jumbo frames (9001 MTU) are supported.
final
lagId → String?
The ID of the LAG.
final
loaIssueTime → DateTime?
The time of the most recent call to DescribeLoa for this connection.
final
location → String?
The location of the connection.
final
ownerAccount → String?
The ID of the AWS account that owns the connection.
final
partnerName → String?
The name of the AWS Direct Connect service provider associated with the connection.
final
providerName → String?
The name of the service provider associated with the connection.
final
region → String?
The AWS Region where the connection is located.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The tags associated with the connection.
final
vlan → int?
The ID of the VLAN.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited