DeleteVirtualInterfaceResponse class

Constructors

DeleteVirtualInterfaceResponse({VirtualInterfaceState? virtualInterfaceState})
DeleteVirtualInterfaceResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
virtualInterfaceState → VirtualInterfaceState?
The state of the virtual interface. The following are the possible values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited