DirectConnectGateway class

Information about a Direct Connect gateway, which enables you to connect virtual interfaces and virtual private gateway or transit gateways.

Constructors

DirectConnectGateway({int? amazonSideAsn, String? directConnectGatewayId, String? directConnectGatewayName, DirectConnectGatewayState? directConnectGatewayState, String? ownerAccount, String? stateChangeError})
DirectConnectGateway.fromJson(Map<String, dynamic> json)
factory

Properties

amazonSideAsn → int?
The autonomous system number (ASN) for the Amazon side of the connection.
final
directConnectGatewayId → String?
The ID of the Direct Connect gateway.
final
directConnectGatewayName → String?
The name of the Direct Connect gateway.
final
directConnectGatewayState → DirectConnectGatewayState?
The state of the Direct Connect gateway. The following are the possible values:
final
hashCode → int
The hash code for this object.
no setterinherited
ownerAccount → String?
The ID of the AWS account that owns the Direct Connect gateway.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateChangeError → String?
The error message if the state of an object failed to advance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited