NewPublicVirtualInterfaceAllocation class

Information about a public virtual interface to be provisioned on a connection.

Constructors

NewPublicVirtualInterfaceAllocation({required int asn, required String virtualInterfaceName, required int vlan, AddressFamily? addressFamily, String? amazonAddress, String? authKey, String? customerAddress, List<RouteFilterPrefix>? routeFilterPrefixes, List<Tag>? tags})

Properties

addressFamily → AddressFamily?
The address family for the BGP peer.
final
amazonAddress → String?
The IP address assigned to the Amazon interface.
final
asn → int
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
final
authKey → String?
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
final
customerAddress → String?
The IP address assigned to the customer interface.
final
hashCode → int
The hash code for this object.
no setterinherited
routeFilterPrefixes → List<RouteFilterPrefix>?
The routes to be advertised to the AWS network in this Region. Applies to public virtual interfaces.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The tags associated with the public virtual interface.
final
virtualInterfaceName → String
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
final
vlan → int
The ID of the VLAN.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited