NewTransitVirtualInterfaceAllocation class

Information about a transit virtual interface to be provisioned on a connection.

Constructors

NewTransitVirtualInterfaceAllocation({AddressFamily? addressFamily, String? amazonAddress, int? asn, String? authKey, String? customerAddress, int? mtu, List<Tag>? tags, String? virtualInterfaceName, int? vlan})

Properties

addressFamily → AddressFamily?
The address family for the BGP peer.
final
amazonAddress → String?
The IP address assigned to the Amazon interface.
final
asn → int?
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
final
authKey → String?
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
final
customerAddress → String?
The IP address assigned to the customer interface.
final
hashCode → int
The hash code for this object.
no setterinherited
mtu → int?
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 9001. The default value is 1500.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The tags associated with the transitive virtual interface.
final
virtualInterfaceName → String?
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
final
vlan → int?
The ID of the VLAN.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited