VirtualInterface class

Information about a virtual interface.

Constructors

VirtualInterface({AddressFamily? addressFamily, String? amazonAddress, int? amazonSideAsn, int? asn, String? authKey, String? awsDeviceV2, List<BGPPeer>? bgpPeers, String? connectionId, String? customerAddress, String? customerRouterConfig, String? directConnectGatewayId, bool? jumboFrameCapable, String? location, int? mtu, String? ownerAccount, String? region, List<RouteFilterPrefix>? routeFilterPrefixes, List<Tag>? tags, String? virtualGatewayId, String? virtualInterfaceId, String? virtualInterfaceName, VirtualInterfaceState? virtualInterfaceState, String? virtualInterfaceType, int? vlan})
VirtualInterface.fromJson(Map<String, dynamic> json)
factory

Properties

addressFamily → AddressFamily?
The address family for the BGP peer.
final
amazonAddress → String?
The IP address assigned to the Amazon interface.
final
amazonSideAsn → int?
The autonomous system number (ASN) for the Amazon side of the connection.
final
asn → int?
The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
final
authKey → String?
The authentication key for BGP configuration. This string has a minimum length of 6 characters and and a maximun lenth of 80 characters.
final
awsDeviceV2 → String?
The Direct Connect endpoint on which the virtual interface terminates.
final
bgpPeers → List<BGPPeer>?
The BGP peers configured on this virtual interface.
final
connectionId → String?
The ID of the connection.
final
customerAddress → String?
The IP address assigned to the customer interface.
final
customerRouterConfig → String?
The customer router configuration.
final
directConnectGatewayId → String?
The ID of the Direct Connect gateway.
final
hashCode → int
The hash code for this object.
no setterinherited
jumboFrameCapable → bool?
Indicates whether jumbo frames (9001 MTU) are supported.
final
location → String?
The location of the connection.
final
mtu → int?
The maximum transmission unit (MTU), in bytes. The supported values are 1500 and 9001. The default value is 1500.
final
ownerAccount → String?
The ID of the AWS account that owns the virtual interface.
final
region → String?
The AWS Region where the virtual interface is located.
final
routeFilterPrefixes → List<RouteFilterPrefix>?
The routes to be advertised to the AWS network in this Region. Applies to public virtual interfaces.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The tags associated with the virtual interface.
final
virtualGatewayId → String?
The ID of the virtual private gateway. Applies only to private virtual interfaces.
final
virtualInterfaceId → String?
The ID of the virtual interface.
final
virtualInterfaceName → String?
The name of the virtual interface assigned by the customer network. The name has a maximum of 100 characters. The following are valid characters: a-z, 0-9 and a hyphen (-).
final
virtualInterfaceState → VirtualInterfaceState?
The state of the virtual interface. The following are the possible values:
final
virtualInterfaceType → String?
The type of virtual interface. The possible values are private and public.
final
vlan → int?
The ID of the VLAN.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited