VirtualInterfaceTestHistory class

Information about the virtual interface failover test.

Constructors

VirtualInterfaceTestHistory({List<String>? bgpPeers, DateTime? endTime, String? ownerAccount, DateTime? startTime, String? status, int? testDurationInMinutes, String? testId, String? virtualInterfaceId})
VirtualInterfaceTestHistory.fromJson(Map<String, dynamic> json)
factory

Properties

bgpPeers → List<String>?
The BGP peers that were put in the DOWN state as part of the virtual interface failover test.
final
endTime → DateTime?
The time that the virtual interface moves out of the DOWN state.
final
hashCode → int
The hash code for this object.
no setterinherited
ownerAccount → String?
The owner ID of the tested virtual interface.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime?
The time that the virtual interface moves to the DOWN state.
final
status → String?
The status of the virtual interface failover test.
final
testDurationInMinutes → int?
The time that the virtual interface failover test ran in minutes.
final
testId → String?
The ID of the virtual interface failover test.
final
virtualInterfaceId → String?
The ID of the tested virtual interface.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited